@@ -655,8 +655,8 @@ class Image(object):
             width, height = geometry[0], geometry[1]
             x, y = geometry[2], geometry[3]
             g = pgmagick.Geometry(x, y, width, height)
-        elif isinstance(geometry, pgmagick.Geometry):
-            g = geometry
+        elif len(geometry) == 1 and isinstance(geometry[0], pgmagick.Geometry):
+            g = geometry[0]
         else:
             raise Exception("not support object", geometry)
         self.img.crop(g)
@@ -696,6 +696,12 @@ class Image(object):
         # TODO: not implemented
         pass
 
+    def font(self, font=None):
+        if font:
+            self.img.font(font)
+        else:
+            return self.img.font()
+
     def scale(self, size, filter_type=None):
         if isinstance(size, float):
             scaled_height = self.img.rows() * size
@@ -707,7 +713,7 @@ class Image(object):
         if filter_type:
             filter_type = getattr(pgmagick.FilterTypes,
                                   "%sFilter" % filter_type.title())
-            pgmagick.Image.filterType(self, filter_type)
+            pgmagick.Image.filterType(self.img, filter_type)
         geometry = pgmagick.Geometry(size)
         self.img.scale(geometry)
 
